@@ -54,7 +54,7 @@ typedef struct {
 
 } SoupAuthDomainDigestPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (SoupAuthDomainDigest, soup_auth_domain_digest, SOUP_TYPE_AUTH_DOMAIN)
+G_DEFINE_FINAL_TYPE_WITH_PRIVATE (SoupAuthDomainDigest, soup_auth_domain_digest, SOUP_TYPE_AUTH_DOMAIN)
 
 static void
 soup_auth_domain_digest_init (SoupAuthDomainDigest *digest)
@@ -118,7 +118,7 @@ soup_auth_domain_digest_get_property (GObject *object, guint prop_id,
 }
 
 /**
- * soup_auth_domain_digest_new:
+ * soup_auth_domain_digest_new: (constructor)
  * @optname1: name of first option, or %NULL
  * @...: option name/value pairs
  *
